==> %e5%af%8c%e8%8c%82%e9%93%be%e5%ae%a22.2.9.tar.gz: c/pages/order/detail/index.js <==
let config = require("../../../config/config.js");
let util = require("../../../utils/util");
let Http = require("../../../utils/HttpBasics");
let app = getApp();
Page({
  /**
   * 页面的初始数据
   */
  data: {
    showModalStatus: false,
    flag: 0,
    order: null,
    orderId: null,
    //存储计时器
    setInter: "",
    mystatus: '',
    staticGamedata: {},
    showIf: false
  },


  powerDrawer: function (e) {
    let that = this;
    // couponOrderStatus
    // 0 未使用
    // 1 已使用
    // 2 已过期
    // 3 已经退款
    if (that.data.mystatus == "" || that.data.mystatus == undefined) {
      wx.navigateTo({
        url: `/pages/orderquanma/index?quancode=${
          e.currentTarget.dataset.quancode
        }&title=${e.currentTarget.dataset.title}&subtitle=${
          e.currentTarget.dataset.subtitle
        }&remark=${e.currentTarget.dataset.remark}&couponorderstatus=${
          e.currentTarget.dataset.couponorderstatus
          }`
      });
    } else {
      wx.navigateTo({
        url: `/pages/orderquanma/index?quancode=${
          e.currentTarget.dataset.quancode
        }&title=${e.currentTarget.dataset.title}&subtitle=${
          e.currentTarget.dataset.subtitle
        }&remark=${e.currentTarget.dataset.remark}&couponorderstatus=${
          that.data.mystatus
        }`
      });
    }
  },
  gotogame: function () {
    let that = this;
    wx.navigateTo({
      url: '/pages/game/index?url=' + that.data.staticGamedata.url + "&id=" + that.data.staticGamedata.id + "&gameId=" + that.data.staticGamedata.gameId,
    })
  },
  // 获取游戏
  getStaticGame(token) {
    let _this = this;
    Http.get({
      url: config.api.getGame,
      data: {
        triggleAction: 3
      }
    }).then(res => {
      if (res.data.id) {
        _this.setData({
          showIf: true
        })
      }
      _this.setData({
        staticGamedata: res.data
      })
    })
      .catch(err => {
        console.log(err);
      })
  },
  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    let that = this;
    this.setData({
      orderId: options.orderId
    });
    wx.showLoading({
      title: "加载中"
    });
    setTimeout(function () {
      wx.hideLoading();
    }, 1500);
    Http.get({
      url: config.api.orderDetail,
      data: {
        orderId: options.orderId
      }
    }).then(res => {
      that.setData({
        order: res.data
      });
      that.getStaticGame()
      //createDate 创建时间
      var createDate = util.formatTime(res.data.createDate, "yyyy-MM-dd hh:mm:ss");
      that.setData({
        createDate: createDate
      });
    });
  },

  /**
   * 发起支付
   */
  orderFunc(e) {
    var that = this;
    wx.showLoading({
      title: "加载中..."
    });

    const orderId = "" + that.data.orderId;
    if (that.data.order.payment > 0) {
      // 支付金额不为0
      Http.post({
        url: config.api.payOrderCreate,
        data: {
          orderId: orderId
        }
      }).then(res => {
        /// Begin payment ----
        var payOrderId = "" + res.data.payOrderId;
        wx.hideLoading();
        wx.requestPayment({
          timeStamp: res.data.timeStamp,
          nonceStr: res.data.nonceStr,
          package: res.data.package,
          signType: (res.data.signType) ? res.data.signType : "MD5",
          paySign: res.data.paySign,
          success: res => {
            that.payOrderUpdate(that.data.orderId, payOrderId, 1,'','',that); // 支付成功
          },
          fail: res => {
            that.payOrderUpdate(that.data.orderId, payOrderId, 2,'','fail',that); 
            return;
          },
        });
        /// End payment  --------
      });
    } else {
      // 免费券
      that.payOrderUpdate(orderId, "0", 1,'','fail') // 支付成功
      wx.showToast({
        title: "支付成功",
        duration: 2000,
        image: "./../../../assets/img/success.png",
      });
    }
  },
  /**
   * 支付订单更新
   */
  payOrderUpdate: (orderId, payOrderId, status, reason,type,_this) => {
    // 支付成功
    Http.post({
        url: config.api.payOrderUpdate,
        data: {
          payOrderId: payOrderId,
          orderId: orderId,
          status: status,
          reason: reason
        }
      })
      .then(res => {
        if (!type) {
          wx.showToast({
            title: "购买成功",
            duration: 2000,
            image: "./../../../assets/img/success.png",
            mask: false,
            success: function () {
              wx.showLoading({
                title: "加载中..."
              });
              setTimeout(function () {
                wx.hideLoading();
              }, 1600);
              setTimeout(() => {
                wx.redirectTo({
                  url: `/pages/order/detail/index?orderId=${orderId}`
                });
              }, 1600);
            }
          });
        }
      })
      .catch(err => {
        console.log(err)
        if (!type) {
          setTimeout(function () {
            _this.payOrderUpdate(orderId, payOrderId, status, reason, type, _this);
          }, 1500)
        }
      });
  },

  /**
   * 生命周期函数--监听页面初次渲染完成
   */
  onShow: function () {
    let that = this;
    // wx.getScreenBrightness({
    //   success: function (res) {
    //     app.globalData.sight=res.value;
    //     console.log(app.globalData.sight);
    //   }
    // });
  },

  /**
   * 生命周期函数--监听页面隐藏
   */
  onHide: function () {},

  /**
   * 页面相关事件处理函数--监听用户下拉动作
   */
  onPullDownRefresh: function () {},

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom: function () {},

  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function () {}
});

==> %e5%af%8c%e8%8c%82%e9%93%be%e5%ae%a23.1.5.tar.gz: c/pages/order/detail/index.js <==
let config = require("../../../config/config.js");
let util = require("../../../utils/util");
let Http = require("../../../utils/HttpBasics");
let app = getApp();
Page({
  /**
   * 页面的初始数据
   */
  data: {
    showModalStatus: false,
    flag: 0,
    order: null,
    orderId: null,
    //存储计时器
    setInter: "",
    mystatus: '',
    staticGamedata: {},
    showIf: false
  },


  powerDrawer: function (e) {
    let that = this;
    // couponOrderStatus
    // 0 未使用
    // 1 已使用
    // 2 已过期
    // 3 已经退款
    if (that.data.mystatus == "" || that.data.mystatus == undefined) {
      wx.navigateTo({
        url: `/pages/orderquanma/index?quancode=${
          e.currentTarget.dataset.quancode
        }&title=${e.currentTarget.dataset.title}&subtitle=${
          e.currentTarget.dataset.subtitle
        }&remark=${e.currentTarget.dataset.remark}&couponorderstatus=${
          e.currentTarget.dataset.couponorderstatus
          }`
      });
    } else {
      wx.navigateTo({
        url: `/pages/orderquanma/index?quancode=${
          e.currentTarget.dataset.quancode
        }&title=${e.currentTarget.dataset.title}&subtitle=${
          e.currentTarget.dataset.subtitle
        }&remark=${e.currentTarget.dataset.remark}&couponorderstatus=${
          that.data.mystatus
        }`
      });
    }
  },
  gotogame: function () {
    let that = this;
    wx.navigateTo({
      url: '/pages/game/index?url=' + that.data.staticGamedata.url + "&id=" + that.data.staticGamedata.id + "&gameId=" + that.data.staticGamedata.gameId,
    })
  },
  // 获取游戏
  getStaticGame(token) {
    let _this = this;
    Http.get({
      url: config.api.getGame,
      data: {
        triggleAction: 3
      }
    }).then(res => {
      if (res.data.id) {
        _this.setData({
          showIf: true
        })
      }
      _this.setData({
        staticGamedata: res.data
      })
    })
      .catch(err => {
        console.log(err);
      })
  },
  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    let that = this;
    this.setData({
      orderId: options.orderId
    });
    wx.showLoading({
      title: "加载中"
    });
    setTimeout(function () {
      wx.hideLoading();
    }, 1500);
    Http.get({
      url: config.api.orderDetail,
      data: {
        orderId: options.orderId
      }
    }).then(res => {
      that.setData({
        order: res.data
      });
      that.getStaticGame()
      //createDate 创建时间
      var createDate = util.formatTime(res.data.createDate, "yyyy-MM-dd hh:mm:ss");
      that.setData({
        createDate: createDate
      });
    });
  },

  /**
   * 发起支付
   */
  orderFunc(e) {
    var that = this;
    wx.showLoading({
      title: "加载中..."
    });

    const orderId = "" + that.data.orderId;
    if (that.data.order.payment > 0) {
      // 支付金额不为0
      Http.post({
        url: config.api.payOrderCreate,
        data: {
          orderId: orderId
        }
      }).then(res => {
        /// Begin payment ----
        var payOrderId = "" + res.data.payOrderId;
        wx.hideLoading();
        wx.requestPayment({
          timeStamp: res.data.timeStamp,
          nonceStr: res.data.nonceStr,
          package: res.data.package,
          signType: (res.data.signType) ? res.data.signType : "MD5",
          paySign: res.data.paySign,
          success: res => {
            wx.showLoading({
              title: '订单正在处理中...',
            })
            setTimeout(function () {
              wx.hideLoading()
            }, 5000)
            that.payOrderUpdate(that.data.orderId, payOrderId, 1,'','',that); // 支付成功
          },
          fail: res => {
            that.payOrderUpdate(that.data.orderId, payOrderId, 2,'','fail',that); 
            return;
          },
        });
        /// End payment  --------
      });
    } else {
      // 免费券
      that.payOrderUpdate(orderId, "0", 1,'','free') // 支付成功
      wx.showToast({
        title: "支付成功",
        duration: 2000,
        image: "./../../../assets/img/success.png",
      });
    }
  },
  /**
   * 支付订单更新
   */
  payOrderUpdate: (orderId, payOrderId, status, reason,type,_this) => {
    // 支付成功
    Http.post({
        url: config.api.payOrderUpdate,
        data: {
          payOrderId: payOrderId,
          orderId: orderId,
          status: status,
          reason: reason
        }
      })
      .then(res => {
        wx.hideLoading()
        if (!type&&type!='free') {
          wx.showToast({
            title: "购买成功",
            duration: 2000,
            image: "./../../../assets/img/success.png",
            mask: false,
            success: function () {
              wx.showLoading({
                title: "加载中..."
              });
              setTimeout(function () {
                wx.hideLoading();
              }, 1600);
              setTimeout(() => {
                wx.redirectTo({
                  url: `/pages/order/detail/index?orderId=${orderId}`
                });
              }, 1600);
            }
          });
        } else if (type == 'free'){
          wx.redirectTo({
            url: `/pages/order/detail/index?orderId=${orderId}`
          });
        }
      })
      .catch(err => {
        console.log(err)
        if (!type) {
          setTimeout(function () {
            _this.payOrderUpdate(orderId, payOrderId, status, reason, type, _this);
          }, 1500)
        }
      });
  },

  /**
   * 生命周期函数--监听页面初次渲染完成
   */
  onShow: function () {
    let that = this;
    // wx.getScreenBrightness({
    //   success: function (res) {
    //     app.globalData.sight=res.value;
    //     console.log(app.globalData.sight);
    //   }
    // });
  },

  /**
   * 生命周期函数--监听页面隐藏
   */
  onHide: function () {},

  /**
   * 页面相关事件处理函数--监听用户下拉动作
   */
  onPullDownRefresh: function () {},

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom: function () {},

  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function () {}
});
